// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:meta/meta.dart';

class Account {
  final IdentityKeys identityKeys;

  Account(this.identityKeys);
}

class IdentityKeys {
  /// Curve22519 base64 encoded key.
  final String curve25519;

  /// Ed25519 base64 encoded key.
  final String ed25519;

  IdentityKeys({
    @required this.curve25519,
    @required this.ed25519,
  });

  factory IdentityKeys.fromJson(Map<String, dynamic> json) {
    return IdentityKeys(
      curve25519: json['curve25519'],
      ed25519: json['ed25519'],
    );
  }

  Map<String, dynamic> toJson() => {
        'curve25519': curve25519,
        'ed25519': ed25519,
      };
}
